define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "هذا الربع",
	"field-quarter-short-relative+1": "الربع القادم",
	"field-tue-relative+-1": "الثلاثاء الماضي",
	"field-year": "السنة",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "الأربعاء الحالي",
	"field-wed-relative+1": "الأربعاء القادم",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "الدقائق",
	"field-tue-narrow-relative+0": "الثلاثاء الحالي",
	"field-tue-narrow-relative+1": "الثلاثاء القادم",
	"field-day-short-relative+-1": "أمس",
	"field-thu-short-relative+0": "الخميس الحالي",
	"dateTimeFormat-short": "{1} في {0}",
	"field-day-relative+0": "اليوم",
	"field-day-short-relative+-2": "أول أمس",
	"field-thu-short-relative+1": "الخميس القادم",
	"field-day-relative+1": "غدًا",
	"field-day-relative+2": "بعد الغد",
	"dateFormatItem-EBhms": "E h:mm:ss B",
	"field-wed-narrow-relative+-1": "الأربعاء الماضي",
	"field-year-narrow": "السنة",
	"field-era-short": "العصر",
	"field-tue-relative+0": "الثلاثاء الحالي",
	"field-tue-relative+1": "الثلاثاء القادم",
	"field-weekdayOfMonth": "يوم عمل من الشهر",
	"field-second-short": "الثواني",
	"dateFormatItem-MMMd": "d MMM",
	"field-weekdayOfMonth-narrow": "يوم عمل/شهر",
	"field-week-relative+0": "هذا الأسبوع",
	"field-month-relative+0": "هذا الشهر",
	"field-week-relative+1": "الأسبوع القادم",
	"field-month-relative+1": "الشهر القادم",
	"field-sun-narrow-relative+0": "الأحد الحالي",
	"field-mon-short-relative+0": "الإثنين الحالي",
	"field-sun-narrow-relative+1": "الأحد القادم",
	"field-mon-short-relative+1": "الإثنين القادم",
	"field-second-relative+0": "الآن",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"field-weekOfMonth": "الأسبوع من الشهر",
	"field-month-short": "الشهر",
	"dateFormatItem-GyMMMEd": "E، d MMM y G",
	"dateFormatItem-yyyyMd": "d‏/M‏/y G",
	"field-day": "يوم",
	"field-dayOfYear-short": "يوم من سنة",
	"field-year-relative+-1": "السنة الماضية",
	"field-sat-short-relative+-1": "السبت الماضي",
	"field-hour-relative+0": "الساعة الحالية",
	"dateFormatItem-yyyyMEd": "E، d/‏M/‏y G",
	"field-wed-relative+-1": "الأربعاء الماضي",
	"dateTimeFormat-medium": "{1} في {0}",
	"field-sat-narrow-relative+-1": "السبت الماضي",
	"field-second": "الثواني",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"dateFormat-long": "d MMMM y G",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-quarter": "ربع السنة",
	"field-week-short": "الأسبوع",
	"field-day-narrow-relative+0": "اليوم",
	"field-day-narrow-relative+1": "غدًا",
	"field-day-narrow-relative+2": "بعد الغد",
	"field-tue-short-relative+0": "الثلاثاء الحالي",
	"field-tue-short-relative+1": "الثلاثاء القادم",
	"field-mon-relative+-1": "الإثنين الماضي",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "الشهر",
	"field-day-narrow": "يوم",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "الدقائق",
	"field-dayperiod": "ص/م",
	"field-sat-short-relative+0": "السبت الحالي",
	"field-sat-short-relative+1": "السبت القادم",
	"dateFormat-medium": "dd‏/MM‏/y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"dateFormatItem-yyyyM": "M‏/y G",
	"field-second-narrow": "الثواني",
	"field-mon-relative+0": "الإثنين الحالي",
	"field-mon-relative+1": "الإثنين القادم",
	"field-day-narrow-relative+-1": "أمس",
	"field-year-short": "السنة",
	"field-day-narrow-relative+-2": "أول أمس",
	"field-quarter-relative+-1": "الربع الأخير",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"field-dayperiod-narrow": "ص/م",
	"field-dayOfYear": "يوم من السنة",
	"field-sat-relative+-1": "السبت الماضي",
	"dateTimeFormat-long": "{1} في {0}",
	"dateFormatItem-Md": "d/‏M",
	"field-hour": "الساعات",
	"dateFormat-full": "EEEE، d MMMM y G",
	"field-month-relative+-1": "الشهر الماضي",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-quarter-short": "ربع السنة",
	"field-sat-narrow-relative+0": "السبت الحالي",
	"field-fri-relative+0": "الجمعة الحالي",
	"field-sat-narrow-relative+1": "السبت القادم",
	"field-fri-relative+1": "الجمعة القادم",
	"dateFormatItem-EBhm": "E h:mm B",
	"field-sun-short-relative+0": "الأحد الحالي",
	"field-sun-short-relative+1": "الأحد القادم",
	"field-week-relative+-1": "الأسبوع الماضي",
	"field-quarter-short-relative+-1": "الربع الأخير",
	"dateFormatItem-Ehm": "E h:mm a",
	"field-quarter-relative+0": "هذا الربع",
	"field-minute-relative+0": "هذه الدقيقة",
	"field-quarter-relative+1": "الربع القادم",
	"field-wed-short-relative+-1": "الأربعاء الماضي",
	"dateFormat-short": "d‏/M‏/y GGGGG",
	"dateFormatItem-Bh": "h B",
	"field-thu-short-relative+-1": "الخميس الماضي",
	"dateFormatItem-yyyyMMMEd": "E، d MMM y G",
	"field-mon-narrow-relative+-1": "الإثنين الماضي",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "الخميس الماضي",
	"dateFormatItem-E": "ccc",
	"field-tue-narrow-relative+-1": "الثلاثاء الماضي",
	"dateFormatItem-H": "HH",
	"field-weekOfMonth-short": "أسبوع من شهر",
	"dateFormatItem-yyyy": "y G",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+0": "الأربعاء الحالي",
	"field-wed-short-relative+1": "الأربعاء القادم",
	"field-sun-relative+-1": "الأحد الماضي",
	"dateTimeFormat-full": "{1} في {0}",
	"dateFormatItem-hm": "h:mm a",
	"dateFormatItem-d": "d",
	"field-weekday": "اليوم",
	"field-day-short-relative+0": "اليوم",
	"field-quarter-narrow-relative+0": "هذا الربع",
	"field-day-short-relative+1": "غدًا",
	"field-sat-relative+0": "السبت الحالي",
	"field-quarter-narrow-relative+1": "الربع القادم",
	"dateFormatItem-h": "h a",
	"field-day-short-relative+2": "بعد الغد",
	"field-sat-relative+1": "السبت القادم",
	"field-dayOfYear-narrow": "يوم/سنة",
	"field-weekdayOfMonth-short": "يوم عمل من شهر",
	"dateFormatItem-MEd": "E، d/‏M",
	"field-zone-narrow": "توقيت",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "الخميس الحالي",
	"field-sun-narrow-relative+-1": "الأحد الماضي",
	"field-mon-short-relative+-1": "الإثنين الماضي",
	"field-thu-narrow-relative+1": "الخميس القادم",
	"field-thu-relative+0": "الخميس الحالي",
	"field-thu-relative+1": "الخميس القادم",
	"dateFormatItem-hms": "h:mm:ss a",
	"field-fri-short-relative+-1": "الجمعة الماضي",
	"field-thu-relative+-1": "الخميس الماضي",
	"field-week": "الأسبوع",
	"dateFormatItem-Ed": "E، d",
	"field-wed-narrow-relative+0": "الأربعاء الحالي",
	"field-wed-narrow-relative+1": "الأربعاء القادم",
	"field-quarter-narrow-relative+-1": "الربع الأخير",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-dayperiod-short": "ص/م",
	"field-fri-short-relative+0": "الجمعة الحالي",
	"field-fri-short-relative+1": "الجمعة القادم",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "الساعات",
	"field-zone-short": "توقيت",
	"field-month-narrow": "الشهر",
	"field-hour-narrow": "الساعات",
	"field-fri-narrow-relative+-1": "الجمعة الماضي",
	"field-year-relative+0": "السنة الحالية",
	"field-year-relative+1": "السنة القادمة",
	"field-era-narrow": "العصر",
	"field-fri-relative+-1": "الجمعة الماضي",
	"dateFormatItem-Bhms": "h:mm:ss B",
	"field-tue-short-relative+-1": "الثلاثاء الماضي",
	"field-minute-narrow": "الدقائق",
	"field-mon-narrow-relative+0": "الإثنين الحالي",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-narrow-relative+1": "الإثنين القادم",
	"field-zone": "التوقيت",
	"dateFormatItem-MMMEd": "E، d MMM",
	"field-weekOfMonth-narrow": "أسبوع/شهر",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"field-weekday-narrow": "اليوم",
	"field-quarter-narrow": "ربع السنة",
	"field-sun-short-relative+-1": "الأحد الماضي",
	"field-day-relative+-1": "أمس",
	"field-day-relative+-2": "أول أمس",
	"field-weekday-short": "اليوم",
	"dateFormatItem-Bhm": "h:mm B",
	"field-sun-relative+0": "الأحد الحالي",
	"field-sun-relative+1": "الأحد القادم",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "يوم",
	"field-week-narrow": "الأسبوع",
	"field-era": "العصر",
	"field-fri-narrow-relative+0": "الجمعة الحالي",
	"field-fri-narrow-relative+1": "الجمعة القادم"
}
//end v1.x content
);